@@ -13,7 +13,7 @@ Readonly::Array our @EXPORT_OK => qw(run);
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Run browser.
 sub run {
@@ -134,7 +134,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<urlview>.
+=over
+
+=item L<urlview>
+
+URL extractor/launcher
+
+=back
 
 =head1 REPOSITORY
 
@@ -148,10 +154,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2013-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
